@@ -4,6 +4,7 @@ import shortuuid
 from dvc.config import Config
 from dvc.path_info import PathInfo
 from dvc.external_repo import external_repo
+from dvc.state import StateNoop
 from dvc.utils import remove
 from dvc.utils.compat import urlparse
 
@@ -21,6 +22,11 @@ def get(url, path, out=None, rev=None):
     tmp_dir = os.path.join(dpath, "." + str(shortuuid.uuid()))
     try:
         with external_repo(cache_dir=tmp_dir, url=url, rev=rev) as repo:
+            # Note: we need to replace state, because in case of getting DVC
+            # dependency on CIFS or NFS filesystems, sqlite-based state
+            # will be unable to obtain lock
+            repo.state = StateNoop()
+
             # Try any links possible to avoid data duplication.
             #
             # Not using symlink, because we need to remove cache after we are
@@ -35,6 +41,7 @@ def get(url, path, out=None, rev=None):
                 Config.SECTION_CACHE_TYPE,
                 "reflink,hardlink,copy",
             )
+
             o = repo.find_out_by_relpath(path)
             with repo.state:
                 repo.cloud.pull(o.get_used_cache())
