@@ -3,27 +3,29 @@ from __future__ import unicode_literals
 
 def pull(
     self,
-    target=None,
+    targets=None,
     jobs=None,
     remote=None,
     all_branches=False,
-    show_checksums=False,
     with_deps=False,
     all_tags=False,
     force=False,
     recursive=False,
 ):
     processed_files_count = self.fetch(
-        target,
+        targets,
         jobs,
         remote=remote,
         all_branches=all_branches,
         all_tags=all_tags,
-        show_checksums=show_checksums,
         with_deps=with_deps,
         recursive=recursive,
     )
-    self.checkout(
-        target=target, with_deps=with_deps, force=force, recursive=recursive
-    )
+    for target in targets or [None]:
+        self.checkout(
+            target=target,
+            with_deps=with_deps,
+            force=force,
+            recursive=recursive,
+        )
     return processed_files_count
